Index: trunk/psLib/src/imageops/psImageConvolve.h
===================================================================
--- trunk/psLib/src/imageops/psImageConvolve.h	(revision 14866)
+++ trunk/psLib/src/imageops/psImageConvolve.h	(revision 15320)
@@ -5,6 +5,6 @@
  * @author Robert DeSonia, MHPCC
  *
- * @version $Revision: 1.29 $ $Name: not supported by cvs2svn $
- * @date $Date: 2007-09-17 20:49:51 $
+ * @version $Revision: 1.30 $ $Name: not supported by cvs2svn $
+ * @date $Date: 2007-10-16 23:31:03 $
  * Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
  */
@@ -153,11 +153,22 @@
 );
 
 /// Convolve a mask image with a kernel
 ///
 /// Returns a mask, grown by the supplied kernel.  Only those pixels specified by the maskVal are grown; the
 /// rest are simply propagated.
-psImage *psImageConvolveMask(const psImage *mask, ///< Mask to convolve
-                             psMaskType maskVal, ///< Mask value to convolve
-                             const psKernel *kernel ///< Kernel by which to convolve
+psImage *psImageConvolveMaskDirect(const psImage *mask, ///< Mask to convolve
+                                   psMaskType maskVal, ///< Mask value to convolve
+                                   const psKernel *kernel ///< Kernel by which to convolve
+    );
+
+/// Convolve a mask image with a kernel, using the FFT
+///
+/// Returns a mask, grown by the supplied kernel.  Only those pixels specified by the maskVal are grown; the
+/// rest are simply propagated.  Uses psImageConvolveFFT to convolve the mask, and then thresholds at the
+/// specified level.
+psImage *psImageConvolveMaskFFT(const psImage *mask, ///< Mask to convolve
+                                psMaskType maskVal, ///< Mask value to convolve
+                                const psKernel *kernel, ///< Kernel by which to convolve
+                                float thresh ///< Threshold (0..1) for convolved floating-point image
     );
 
@@ -153,11 +153,22 @@
 );
 
-/// Convolve a mask image with a kernel
+/// Convolve a mask image with a kernel, using direct convolution
 ///
 /// Returns a mask, grown by the supplied kernel.  Only those pixels specified by the maskVal are grown; the
